# -*- coding: utf-8 -*-
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import generators
from __future__ import division

import os

from PySide2 import QtCore, QtGui, QtWidgets
from PySide2.QtUiTools import QUiLoader

from maya.app.general import mayaMixin
from maya import cmds

from PySide2 import QtWidgets

CURRENT_PATH = os.path.dirname(os.path.abspath(__file__))


class View(mayaMixin.MayaQWidgetDockableMixin, QtWidgets.QMainWindow):
    def __init__(self, *args, **kwargs):
        super(View, self).__init__(*args, **kwargs)
        self.ui = QUiLoader().load(os.path.join(CURRENT_PATH, "ui", "MayaAutoPackageReloader.ui"))
        self.setCentralWidget(self.ui)
        self.setWindowTitle(self.ui.windowTitle())
        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)



# -*- coding: utf-8 -*-
"""サーバー関連

"""
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import generators
from __future__ import division

import sys
import os

import time

from watchdog.observers import Observer
from watchdog.events import FileSystemEventHandler


class ReloadServer(object):
    def __init__(self):
        self.observer = None

        self.is_monitor = False

    def start(self, target_path):
        folder_name = os.path.basename(target_path)

        print("folder_name", folder_name)

        self.observer = Observer()
        self.observer.schedule(MayaModuleReloadEventhandler(folder_name), target_path, recursive=True)

        self.observer.start()
        self.is_monitor = True

        try:
            while self.is_monitor:
                time.sleep(1)
        finally:
            self.observer.stop()
            self.observer.join()

    def stop(self):
        self.is_monitor = False


class MayaModuleReloadEventhandler(FileSystemEventHandler):
    def __init__(self, folder_name):
        self.folder_name = folder_name

    def on_any_event(self, event):

        for k in list(sys.modules):
            if k.startswith(self.folder_name):
                print(k)
                del sys.modules[k]

        print("__module__", __package__)
        print("__name__", __name__)

        print(self.folder_name)


class SingletonMultiInstanceError(Exception):
    pass



# -*- coding: utf-8 -*-
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import generators
from __future__ import division

from .controller import main

__version__ = '0.0.1'



#!/usr/bin/env python2
# -*- coding: utf-8 -*-
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import generators
from __future__ import division

import threading

from . import view
from . import server

from PySide2 import QtCore

from maya import cmds


class Controller(object):
    def __init__(self):
        self.gui = view.View()

        self.reload_server = server.ReloadServer()
        self._filter = None

        self.setup_event()

    def setup_event(self):
        self.gui.ui.OpenFolderButton.clicked.connect(self.select_folder_dialog)
        self.gui.ui.StartMonitorButton.clicked.connect(self.start_monitor)
        self.gui.ui.EndMonitorButton.clicked.connect(self.end_monitor)

        self._filter = Filter(self.end_monitor)
        self.gui.installEventFilter(self._filter)

    def select_folder_dialog(self):
        select_path = cmds.fileDialog2(dialogStyle=2, fileMode=3)[0]
        self.gui.ui.PathLineEdit.setText(select_path)

    def start_monitor(self):
        target_path = self.gui.ui.PathLineEdit.text()

        thread_1 = threading.Thread(name="MonitoringThread", target=self.reload_server.start, args=[target_path])
        thread_1.start()

        self.gui.ui.StartMonitorButton.setEnabled(False)
        self.gui.ui.EndMonitorButton.setEnabled(True)

    def end_monitor(self):
        self.reload_server.stop()

        self.gui.ui.StartMonitorButton.setEnabled(True)
        self.gui.ui.EndMonitorButton.setEnabled(False)


class Filter(QtCore.QObject):
    def __init__(self, close_event):
        super(Filter, self).__init__()
        self.__close_event = close_event

    def eventFilter(self, widget, event):
        if event.type() == QtCore.QEvent.Close:
            self.__close_event()
            print("cloe call.")

        return False


def main():
    global MayaAutoReloader

    try:
        MayaAutoReloader.gui.close()
    except:
        pass

    MayaAutoReloader = Controller()
    MayaAutoReloader.gui.show()



from setuptools import setup
import re
import io

about = {}

__version__ = re.search(
    r'__version__\s*=\s*[\'"]([^\'"]*)[\'"]',  # It excludes inline comment too
    io.open('src/mayarepacker/__init__.py', encoding='utf_8_sig').read()).group(1)


setup(
    name="mayarepacker",
    version=__version__,
)
